#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
stati.exceptions
~~~~~~~~~~~~~~~~~~~

Stati exceptions module

:copyright: (c) 2012 by GottWall team, see AUTHORS for more details.
:license: BSD, see LICENSE for more details.
:github: http://github.com/Lispython/stati-python
"""

class InvalidData(Exception):
    pass
